@@ -18,7 +18,8 @@ TRAITS = [
     # The virt driver supports attaching a network interface after boot and
     # specifying a device tag for the interface
     'ATTACH_INTERFACE_WITH_TAG',
-
+    # The virt driver supports Packed virtqueue format
+    'VIRTIO_PACKED',
     # traits corresponding to the allowed values of "hw_vif_model"
     # image metadata property
     # https://github.com/openstack/nova/blob/1f74441/nova/network/model.py#L136-L149
@@ -34,4 +35,5 @@ TRAITS = [
     'VIF_MODEL_VIRTIO',
     'VIF_MODEL_VMXNET',
     'VIF_MODEL_VMXNET3',
+    'VIF_MODEL_IGB',
 ]
